@@ -10,7 +10,7 @@ def drop(self, **kwargs):
     Parameters
     -------------
     *kwargs
-        Possible arguments: var, year, month, day 
+        Possible arguments: var, year, month, day
 
         Note: this uses partial matches. So years, month, variable etc. will also work
 
@@ -39,9 +39,9 @@ def drop(self, **kwargs):
 
     >>> ds.drop(variable = ['var1', 'var2', 'var2'])
 
-    If you wanted to remove the 29th Feburary you would do the following: 
+    If you wanted to remove the 29th Feburary you would do the following:
 
-    >>> ds.drop(month = 2, day = 29) 
+    >>> ds.drop(month = 2, day = 29)
 
 
     """
@@ -51,7 +51,6 @@ def drop(self, **kwargs):
 
     valids = ["var", "mon", "day", "year", "time"]
 
-
     for key in kwargs:
         key_check = 0
         for vv in valids:
@@ -98,6 +97,9 @@ def drop(self, **kwargs):
         if ("mon" in key) or ("day" in key) or ("year" in key):
             vars = kwargs[key]
 
+            if type(vars) is range:
+                vars = list(vars)
+
             if type(vars) is not list:
                 vars = [vars]
 
@@ -107,7 +109,6 @@ def drop(self, **kwargs):
 
             vars = str_flatten(vars, ",")
 
-
             # create the cdo command and run it
             if "day" in key:
                 temporal_command = temporal_command + f",day={vars}"
@@ -116,8 +117,5 @@ def drop(self, **kwargs):
             if "year" in key:
                 temporal_command = temporal_command + f",year={vars}"
 
-        
     if len(temporal_command) > len("cdo -delete"):
         run_this(temporal_command, self, output="ensemble")
-
-
